@@ -74,8 +74,8 @@ class Connection(ABC):
         while True:
             try:
                 await callback(self._devices, self)
-            except Exception:  # pylint: disable=broad-except
-                pass
+            except Exception as e:  # pylint: disable=broad-except
+                _LOGGER.error("Callback error: %s", e)
 
             await asyncio.sleep(interval)
 
@@ -113,7 +113,7 @@ class Connection(ABC):
         elif isinstance(frame, responses.MixerParameters):
             device.mixers.set_parameters(frame.data[DATA_MIXERS])
 
-        elif isinstance(frame, responses.DataStructure):
+        elif isinstance(frame, responses.DataSchema):
             device.schema = frame.data
 
         elif isinstance(frame, requests.CheckDevice):
