@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from abc import abstractmethod
 import time
-from typing import Any, Dict, Final, List, Optional, Type
+from typing import Any, Dict, Final, List, Optional, Tuple, Type
 
 from . import requests
 from .constants import (
@@ -153,13 +153,12 @@ Mixers:
         """Returns list of editable parameters."""
         parameters: List[str] = []
         parameters.extend(DEVICE_PARAMS)
-        parameters.append(PARAM_BOILER_CONTROL)
         return parameters
 
     @property
     @abstractmethod
-    def required_frames(self) -> List[Type[Request]]:
-        """Returns list of required frames."""
+    def required_frames(self) -> Tuple[Type[Request], ...]:
+        """Returns tuple of required frames."""
 
 
 class EcoMAX(Device):
@@ -230,14 +229,21 @@ class EcoMAX(Device):
         return fuel_burned
 
     @property
-    def required_frames(self) -> List[Type[Request]]:
-        """Returns list of required frames."""
-        return [
+    def required_frames(self) -> Tuple[Type[Request], ...]:
+        """Returns tuple of required frames."""
+        return (
             requests.UID,
             requests.Password,
             requests.Parameters,
             requests.MixerParameters,
-        ]
+        )
+
+    @property
+    def editable_parameters(self) -> List[str]:
+        """Returns list of editable parameters."""
+        parameters = super().editable_parameters
+        parameters.append(PARAM_BOILER_CONTROL)
+        return parameters
 
 
 class EcoSTER(Device):
